bayespy.inference.vmp.nodes.gaussian.GaussianGammaMoments
=========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianGammaMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaMoments.__init__
      ~GaussianGammaMoments.add_converter
      ~GaussianGammaMoments.compute_fixed_moments
      ~GaussianGammaMoments.from_values
      ~GaussianGammaMoments.get_converter
      ~GaussianGammaMoments.get_instance_conversion_kwargs
      ~GaussianGammaMoments.get_instance_converter
   
   

   
   
   